==> apache-marmotta-3.2.1-src.zip: apache-marmotta-3.2.1/libraries/kiwi/kiwi-reasoner/src/main/java/org/apache/marmotta/kiwi/reasoner/model/query/QueryResult.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.marmotta.kiwi.reasoner.model.query;

import org.apache.marmotta.commons.sesame.model.StatementCommons;
import org.apache.marmotta.kiwi.model.rdf.KiWiNode;
import org.apache.marmotta.kiwi.model.rdf.KiWiTriple;
import org.apache.marmotta.kiwi.reasoner.model.program.VariableField;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

/**
 * Represent the result of a pattern query of a rule body against the triple store.
 * <p/>
 * User: sschaffe
 */
public class QueryResult {

    private Map<VariableField,KiWiNode> bindings;

    private Set<KiWiTriple> justifications;

    public QueryResult() {
        bindings       = new HashMap<VariableField, KiWiNode>();
        justifications = StatementCommons.newQuadrupleSet();
    }

    public QueryResult(Map<VariableField, KiWiNode> bindings, Set<KiWiTriple> justifications) {
        this.bindings = bindings;
        this.justifications = justifications;
    }

    public Map<VariableField, KiWiNode> getBindings() {
        return bindings;
    }

    public Set<KiWiTriple> getJustifications() {
        return justifications;
    }

}

==> apache-marmotta-3.4.0-src.zip: apache-marmotta-3.4.0/libraries/kiwi/kiwi-reasoner/src/main/java/org/apache/marmotta/kiwi/reasoner/model/query/QueryResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.marmotta.kiwi.reasoner.model.query;

import org.apache.marmotta.commons.sesame.model.StatementCommons;
import org.apache.marmotta.kiwi.model.rdf.KiWiNode;
import org.apache.marmotta.kiwi.model.rdf.KiWiTriple;
import org.apache.marmotta.kiwi.reasoner.model.program.VariableField;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/**
 * Represent the result of a pattern query of a rule body against the triple store.
 * <p/>
 * User: sschaffe
 */
public class QueryResult {

    private Map<VariableField,KiWiNode> bindings;

    private Set<KiWiTriple> justifications;

    public QueryResult() {
        bindings       = new HashMap<>();
        justifications = StatementCommons.newQuadrupleSet();
    }

    public QueryResult(Map<VariableField, KiWiNode> bindings, Set<KiWiTriple> justifications) {
        this.bindings = bindings;
        this.justifications = justifications;
    }

    public Map<VariableField, KiWiNode> getBindings() {
        return bindings;
    }

    public Set<KiWiTriple> getJustifications() {
        return justifications;
    }

}
